<?php
namespace FiloBlu\ExtInventory\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use FiloBlu\ExtInventory\Helper\Data;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Psr\Log\LoggerInterface;
use Magento\Store\Model\StoreManagerInterface;
use Magento\ConfigurableProduct\Model\Product\Type\Configurable;

class CheckProductsBeforePlaceOrder implements ObserverInterface
{

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;


    const OBSERVER_ENABLE_PATH = 'msi/observer/sales_order_place_before';

    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;
    /**
     * @var Configurable
     */
    private $configurable;
    /**
     * @var Data
     */
    private $helper;


    /**
     * CheckProductsBeforePlaceOrder constructor.
     * @param Data $helper
     * @param ScopeConfigInterface $scopeConfig
     * @param LoggerInterface $logger
     * @param StoreManagerInterface $storeManager
     * @param Configurable $configurable
     */
    public function __construct(
        Data $helper,
        ScopeConfigInterface $scopeConfig,
        LoggerInterface $logger,
        StoreManagerInterface $storeManager,
        Configurable  $configurable)
    {
        $this->scopeConfig = $scopeConfig;
        $this->logger = $logger;
        $this->storeManager = $storeManager;
        $this->configurable = $configurable;
        $this->helper = $helper;
    }


    /**
     * @param Observer $observer
     */
    public function execute(Observer $observer){
            if(!$this->scopeConfig->getValue(self::OBSERVER_ENABLE_PATH)){
                return;
            }
            /** @var \Magento\Sales\Model\Order $order */
            $order = $observer->getOrder();
            $items = $order->getItems();
            $websiteCode = $this->storeManager->getWebsite()->getCode();
            foreach ($items as $item){
                if($item->getProductType() == "simple"){
                    $salableQty = $this->helper->getSalableQty($item,$websiteCode);
                    $requestedQty= $item->getQtyOrdered();
                    if($requestedQty > $salableQty){
                       //throw exception
                        throw new \Magento\Framework\Exception\LocalizedException(
                            __('Product with sku '.$item->getSku().' is not available.')
                        );
                    }
                }
            }
    }


}